%%%
%%% Input data
%%% 

%%% The following dynamic predicates are used to store input file names

:- dynamic	fileWNHierarchy/1, fileWNBlocks/1, fileTCOHierarchy/1, fileTCOIncompatibilities/1, fileWN2TCOMapping/1. %/

%%% The default file names are (editable information):

% WordNet Hierarchy file name:
fileWNHierarchy('WordNetHierarchy2.2.pl').		% Place WordNet Hierarchy file name in quotation marks

% WordNet Inheritance Blocks file name:
fileWNBlocks('WordNetInheritanceBlocks2.2.pl').	% Place WordNet Inheritance Blocks file name in quotation marks

% TCO Hierarchy file name:
fileTCOHierarchy('TCOHierarchy2.2.pl').			% Place TCO Hierarchy file name in quotation marks

% TCO Incompatibilities file name:
fileTCOIncompatibilities('TCOIncompatibilities2.2.pl'). % Place TCO Incompatibilities file name in quotation marks

% WordNet to TCO Mapping file name:
fileWN2TCOMapping('WordNet2TCOMapping2.2.pl').		% Place WordNet to TCO Mapping file name in quotation marks

%%% The following predicates can be used to dynamically obtain input file names:
%%%	1. getWordNetHierarchyFile/1 %/
%%%	2. getWordNetInheritableBlocksFile/1 %/
%%%	3. getTCOHierarchyFile/1 %/
%%%	4. getTCOIncompatibilitiesFile/1 %/
%%%	5. getWordNet2TCOMappingFile/1 %/

%%% getWordNetHierarchyFile(out F)
%%%	F: WordNet Hierarchy file name

getWordNetHierarchyFile(F):-
		fileWNHierarchy(F).

%%% getWordNetInheritanceBlocksFile(out F)
%%%	F: WordNet Inheritance Blocks file name

getWordNetInheritanceBlocksFile(F):-
		fileWNBlocks(F).

%%% getTCOHierarchyFile(out F)
%%%	F: TCO Hierarchy file name

getTCOHierarchyFile(F):-
		fileTCOHierarchy(F).

%%% getTCOIncompatibilitiesFile(out F)
%%%	F: TCO Incompatibilities file name

getTCOIncompatibilitiesFile(F):-
		fileTCOIncompatibilities(F).

%%% getWordNet2TCOMappingFile(out F)
%%%	F: WordNet to TCO Mapping file name

getWordNet2TCOMappingFile(F):-
		fileWN2TCOMapping(F).

%%% The following predicates can be used to dynamically update input file names:
%%%	1. setWordNetHierarchyFile/1 %/
%%%	2. setWordNetInheritableBlocksFile/1 %/
%%%	3. setTCOHierarchyFile/1 %/
%%%	4. setTCOIncompatibilitiesFile/1 %/
%%%	5. setWordNet2TCOMappingFile/1 %/

%%% setWordNetHierarchyFile(in F)
%%%	F: WordNet Hierarchy file name
%%%	Output:  WordNet Hierarchy file name is updated

setWordNetHierarchyFile(F):-
		retractall((fileWNHierarchy(_))),
		assert((fileWNHierarchy(F))).

%%% setWordNetInheritanceBlocksFile(in F)
%%%	F: WordNet Inheritance Blocks file name
%%%	Output:  WordNet Inheritance Blocks file name is updated

setWordNetInheritanceBlocksFile(F):-
		retractall((fileWNBlocks(_))),
		assert((fileWNBlocks(F))).

%%% setTCOHierarchyFile(in F)
%%%	F: TCO Hierarchy file name
%%%	Output:  TCO Hierarchy file name is updated

setTCOHierarchyFile(F):-
		retractall((fileTCOHierarchy(_))),
		assert((fileTCOHierarchy(F))).

%%% setTCOIncompatibilitiesFile(in F)
%%%	F: TCO Incompatibilities file name
%%%	Output:  TCO Incompatibilities file name is updated

setTCOIncompatilitiesFile(F):-
		retractall((fileTCOIncompatibilities(_))),
		assert((fileTCOIncompatibilities(F))).

%%% setWordNet2TCOMappingFile(in F)
%%%	F: WordNet to TCO Mapping file name
%%%	Output:  WordNet to TCO Mapping file name is updated

setWordNet2TCOMappingFile(F):-
		retractall((fileWN2TCOMapping(_))),
		assert((fileWN2TCOMapping(F))).

%%%
%%% End of Input data
%%%

%%%
%%% Output data
%%%

%%% The following dynamic predicates are used to store input file names

:- dynamic	fileInconsistencies/1, fileTopOntology/1, fileExpandedMapping/1. %/

%%% The default file names are (editable information):

% Inconsistencies file name:
fileInconsistencies('Inconsistencies2.2.txt').		% Place Inconsistencies file name in quotation marks

% Top Ontology file name:
fileTopOntology('topontology-2.2.txt').			% Place Top Ontology file name in quotation marks

% Expanded mapping file name:
fileExpandedMapping('wei_expand-DEF-version2.2.txt').	% Place Expanded mapping file name in quotation marks

%%% The following predicates can be used to dynamically obtain the output file names:
%%%	1. getInconsistenciesFile/1 %/
%%%	2. getTopOntologyFile/1 %/
%%%	3. getExpandedMappingFile/1 %/

%%% getInconsistenciesFile(out F)
%%%	F: Inconsistencies file name

getInconsistenciesFile(F):-
		fileInconsistencies(F).

%%% getTopOntologyFile(out F)
%%%	F: Top Ontology file name

getTopOntologyFile(F):-
		fileTopOntology(F).

%%% getExpandedMappingFile(out F)
%%%	F: Expanded mapping file name

getExpandedMappingFile(F):-
		fileExpandedMapping(F).

%%% The following predicates can be used to dynamically update the output file names:
%%%	1. setInconsistenciesFile/1 %/
%%%	2. setTopOntologyFile/1 %/
%%%	3. setExpandedMappingFile/1 %/

%%% setInconsistenciesFile(in F)
%%%	F: Inconsistencies file name
%%%	Output:  Inconsistencies file name is updated

setInconsistenciesFile(F):-
		retractall((fileInconsistencies(_))),
		assert((fileInconsistencies(F))).

%%% setTopOntologyFile(in F)
%%%	F: Top Ontology file name
%%%	Output:  Top Ontology file name is updated

setTopOntologyFile(F):-
		retractall((fileTopOntology(_))),
		assert((fileTopOntology(F))).

%%% setExpandedMappingFile(in F)
%%%	F: Expanded mapping file name
%%%	Output:  Expanded mapping file name is updated

setExpandedMappingFile(F):-
		retractall((fileExpandedMapping(_))),
		assert((fileExpandedMapping(F))).

%%%
%%% End of Output data
%%%